@@ -101,7 +101,7 @@ FrMimeTypeDescription mime_type_desc[] = {
 	{ "application/x-cpio",                 ".cpio",     NULL, 0 },
 	{ "application/x-deb",                  ".deb",      NULL, 0 },
 	{ "application/x-ear",                  ".ear",      N_("Ear (.ear)"), 0 },
-	{ "application/x-executable",           ".exe",      N_("Self-extracting zip (.exe)"), 0 },
+	{ "application/x-ms-dos-executable",    ".exe",      N_("Self-extracting zip (.exe)"), 0 },
 	{ "application/x-gzip",                 ".gz",       NULL, 0 },
 	{ "application/x-java-archive",         ".jar",      N_("Jar (.jar)"), 0 },
 	{ "application/x-lha",                  ".lzh",      N_("Lha (.lzh)"), 0 },
@@ -136,7 +136,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".cpio", "application/x-cpio" },
 	{ ".deb", "application/x-deb" },
 	{ ".ear", "application/x-ear" },
-	{ ".exe", "application/x-executable" },
+	{ ".exe", "application/x-ms-dos-executable" },
 	{ ".gz", "application/x-gzip" },
 	{ ".iso", "application/x-cd-image" },
 	{ ".jar", "application/x-java-archive" },
@@ -515,12 +515,9 @@ static void
 register_commands (void)
 {
 	/* The order here is important. Commands registered earlier have higher
-	 * priority; for example zip archives will be opened using 7Z instead
-	 * of ZIP.  However commands that can read and write a file format
+	 * priority.  However commands that can read and write a file format
 	 * have higher priority over commands that can only read the same
-	 * format, regardless of the registration order; for example rar
-	 * archives will be opened with 7Z only if the rar utility is not
-	 * installed because 7z cannot modify rar archives. */
+	 * format, regardless of the registration order. */
 
 	register_command (FR_TYPE_COMMAND_TAR);
 	register_command (FR_TYPE_COMMAND_CFILE);
@@ -631,6 +628,54 @@ add_if_non_present (int *a,
 }
 
 
+static int
+cmp_mime_type_by_extension (const void *p1, 
+			    const void *p2)
+{
+	int i1 = * (int*) p1;
+	int i2 = * (int*) p2;
+	
+	return strcmp (mime_type_desc[i1].default_ext, mime_type_desc[i2].default_ext);
+}
+
+
+static int
+cmp_mime_type_by_description (const void *p1, 
+			      const void *p2)
+{
+	int i1 = * (int*) p1;
+	int i2 = * (int*) p2;
+	
+	return g_utf8_collate (_(mime_type_desc[i1].name), _(mime_type_desc[i2].name));
+}
+
+
+static void
+sort_mime_types (int *a,
+                 int(*compar)(const void *, const void *))
+{
+	int n = 0;
+
+	while (a[n] != -1) 
+		n++;		
+	qsort (a, n, sizeof (int), compar);
+}
+
+
+void
+sort_mime_types_by_extension (int *a)
+{
+	sort_mime_types (a, cmp_mime_type_by_extension);
+}
+
+
+void
+sort_mime_types_by_description (int *a)
+{
+	sort_mime_types (a, cmp_mime_type_by_description);
+}
+
+
 static void
 compute_supported_archive_types (void)
 {
@@ -676,27 +721,13 @@ compute_supported_archive_types (void)
 static char *
 get_uri_from_command_line (const char *path)
 {
-	char *full_path;
-	char *uri;
-
-	if (strstr (path, "://") != NULL)
-		return g_strdup (path);
-
-	if (g_path_is_absolute (path))
-		full_path = g_strdup (path);
-	else {
-		char *current_dir;
-
-		current_dir = g_get_current_dir ();
-		full_path = g_build_filename (current_dir,
-					      path,
-					      NULL);
-		g_free (current_dir);
-	}
-
-	uri = g_filename_to_uri (full_path, NULL, NULL);
-	g_free (full_path);
-
+	GFile *file;
+	char  *uri;
+		
+	file = g_file_new_for_commandline_arg (path);
+	uri = g_file_get_uri (file);
+	g_object_unref (file);
+	
 	return uri;
 }
 
@@ -860,20 +891,20 @@ save_session (GnomeClient *client)
 
 		key = g_strdup_printf ("archive%d", i);
 		if ((window->archive == NULL) || (window->archive->file == NULL)) {
-			g_key_file_set_string (key_file, "Sessione", key, "");
+			g_key_file_set_string (key_file, "Session", key, "");
 		}
 		else {
 			char *uri;
 
 			uri = g_file_get_uri (window->archive->file);
-			g_key_file_set_string (key_file, "Sessione", key, uri);
+			g_key_file_set_string (key_file, "Session", key, uri);
 			g_free (uri);
 		}
 		g_free (key);
 
 		i++;
 	}
-	g_key_file_set_integer (key_file, "Sessione", "archives", i);
+	g_key_file_set_integer (key_file, "Session", "archives", i);
 
 	path = get_real_path_for_prefix (gnome_client_get_config_prefix (client));
 	file = g_file_new_for_path (path);
